@@ -28,11 +28,17 @@ def visit_Call(
     parent: ast.AST,
 ) -> Iterable[Tuple[Offset, TokenFunc]]:
     if (
-        NAME in state.from_imports[MODULE]
-        and isinstance(node.func, ast.Name)
+        isinstance(node.func, ast.Name)
+        and NAME in state.from_imports[MODULE]
         and node.func.id == NAME
         and len(node.args) == 0
         and not any(k.arg == "length" for k in node.keywords)
+    ) or (
+        isinstance(node.func, ast.Attribute)
+        and node.func.attr == NAME
+        and "crypto" in state.from_imports["django.utils"]
+        and isinstance(node.func.value, ast.Name)
+        and node.func.value.id == "crypto"
     ):
         yield ast_start_offset(node), partial(
             add_length_argument,
