@@ -30,10 +30,8 @@ def visit_ImportFrom(
     node: ast.ImportFrom,
     parent: ast.AST,
 ) -> Iterable[Tuple[Offset, TokenFunc]]:
-    if node.level != 0 or node.module != MODULE:
-        return
-
-    yield ast_start_offset(node), partial(update_imports, node=node, name_map=NAMES)
+    if node.level == 0 and node.module == MODULE:
+        yield ast_start_offset(node), partial(update_imports, node=node, name_map=NAMES)
 
 
 @fixer.register(ast.Name)
@@ -42,8 +40,24 @@ def visit_Name(
     node: ast.Name,
     parent: ast.AST,
 ) -> Iterable[Tuple[Offset, TokenFunc]]:
-    name = node.id
-    if name in NAMES and name in state.from_imports[MODULE]:
+    if (name := node.id) in NAMES and name in state.from_imports[MODULE]:
+        yield ast_start_offset(node), partial(
+            find_and_replace_name, name=name, new=NAMES[name]
+        )
+
+
+@fixer.register(ast.Attribute)
+def visit_Attribute(
+    state: State,
+    node: ast.Attribute,
+    parent: ast.AST,
+) -> Iterable[Tuple[Offset, TokenFunc]]:
+    if (
+        (name := node.attr) in NAMES
+        and isinstance(node.value, ast.Name)
+        and node.value.id == "encoding"
+        and "encoding" in state.from_imports["django.utils"]
+    ):
         yield ast_start_offset(node), partial(
             find_and_replace_name, name=name, new=NAMES[name]
         )
